.. redirect-from:: /users/prev_whats_new/github_stats_3.6.2

.. _github-stats-3-6-2:

GitHub statistics for 3.6.2 (Nov 02, 2022)
==========================================

GitHub statistics for 2022/10/08 (tag: v3.6.1) - 2022/11/02

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 21 issues and merged 86 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/75?closed=1>`__

The following 22 authors contributed 27 commits.

* Antony Lee
* Carsten Schnober
* dependabot[bot]
* Elliott Sales de Andrade
* hannah
* j1642
* Jaco Verster
* jacoverster
* Jae-Joon Lee
* Jeffrey Aaron Paul
* jeffreypaul15
* Jody Klymak
* Kostya Farber
* Kyle Sunden
* Martok
* Muhammad Abdur Rakib
* Oscar Gustafsson
* Pavel Grunt
* Ruth Comer
* Thomas A Caswell
* Tiger Nie
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (86):

* :ghpull:`24341`: Backport PR #24301 on branch v3.6.x (Restore get_renderer function in deprecated tight_layout)
* :ghpull:`24301`: Restore get_renderer function in deprecated tight_layout
* :ghpull:`24337`: Backport PR #24238 on branch v3.6.x (Update example and docstring to encourage the use of functools.partial in FuncAnimation)
* :ghpull:`24336`: Backport PR #24335 on branch v3.6.x (Fix missing word in ImageMagickWriter docstring.)
* :ghpull:`20358`: Updates example and docstring to encourage the use of functools.partial in FuncAnimation
* :ghpull:`24238`: Update example and docstring to encourage the use of functools.partial in FuncAnimation
* :ghpull:`24335`: Fix missing word in ImageMagickWriter docstring.
* :ghpull:`24330`: Backport PR #24282 on branch v3.6.x (Fix some minor docstring typos)
* :ghpull:`24323`: Backport PR #24320 on branch v3.6.x (DOC: add warning note to imsave)
* :ghpull:`24282`: Fix some minor docstring typos
* :ghpull:`24327`: Backport PR #24310 on branch v3.6.x (show axes changing in animate decay example)
* :ghpull:`24310`: show axes changing in animate decay example
* :ghpull:`24324`: Backport PR #24259 on branch v3.6.x (Move empty hexbin fix to make_norm_from_scale.)
* :ghpull:`24325`: Backport PR #24095 on branch v3.6.x (nb/webagg: Move mouse events to outer canvas div)
* :ghpull:`24326`: Backport PR #24318 on branch v3.6.x (Bump pypa/cibuildwheel from 2.11.1 to 2.11.2)
* :ghpull:`24318`: Bump pypa/cibuildwheel from 2.11.1 to 2.11.2
* :ghpull:`24095`: nb/webagg: Move mouse events to outer canvas div
* :ghpull:`24259`: Move empty hexbin fix to make_norm_from_scale.
* :ghpull:`24320`: DOC: add warning note to imsave
* :ghpull:`24297`: Backport PR #24294 on branch v3.6.x (Run test if fontconfig is present)
* :ghpull:`24294`: Run test if fontconfig is present
* :ghpull:`24286`: Backport PR #24284 on branch v3.6.x (Remove comment about cmap from voxels docstring)
* :ghpull:`24284`: Remove comment about cmap from voxels docstring
* :ghpull:`24280`: Backport PR #24145 on branch v3.6.x (Updated Angles on Bracket arrow styles example to make angles clear #23176)
* :ghpull:`24145`: Updated Angles on Bracket arrow styles example to make angles clear #23176
* :ghpull:`24270`: Backport PR #24265 on branch v3.6.x (Restore (and warn on) seaborn styles in style.library)
* :ghpull:`24271`: Backport PR #24266 on branch v3.6.x (TST: Increase fp tolerance on more tests for new NumPy)
* :ghpull:`24266`: TST: Increase fp tolerance on more tests for new NumPy
* :ghpull:`24265`: Restore (and warn on) seaborn styles in style.library
* :ghpull:`24267`: Backport PR #24261 on branch v3.6.x (Fix pie chart in demo_agg_filter.py)
* :ghpull:`24261`: Fix pie chart in demo_agg_filter.py
* :ghpull:`24258`: Backport PR #24108 on branch v3.6.x (Add 3D plots to plot_types doc page)
* :ghpull:`24108`: Add 3D plots to plot_types doc page
* :ghpull:`24255`: Backport PR #24250 on branch v3.6.x (Fix key reporting in pick events)
* :ghpull:`24250`: Fix key reporting in pick events
* :ghpull:`24237`: Backport PR #24197 on branch v3.6.x (Properly set and inherit backend_version.)
* :ghpull:`24197`: Properly set and inherit backend_version.
* :ghpull:`24234`: Backport PR #23607 on branch v3.6.x (DOC: document that appearance is part of our stable API)
* :ghpull:`24233`: Backport PR #23985 on branch v3.6.x (Improve rubberband rendering in wx and tk)
* :ghpull:`24232`: Backport PR #24096 on branch v3.6.x ([DOC]: Add simple animation scatter plot to the example documentation)
* :ghpull:`24231`: Backport PR #24009 on branch v3.6.x (Fix evaluating colormaps on non-numpy arrays)
* :ghpull:`24230`: Backport PR #24229 on branch v3.6.x (FIX: do not mutate dictionaries passed in by user)
* :ghpull:`23607`: DOC: document that appearance is part of our stable API
* :ghpull:`23985`: Improve rubberband rendering in wx and tk
* :ghpull:`24096`: [DOC]: Add simple animation scatter plot to the example documentation
* :ghpull:`24009`: Fix evaluating colormaps on non-numpy arrays
* :ghpull:`24229`: FIX: do not mutate dictionaries passed in by user
* :ghpull:`24223`: Backport PR #24184 on branch v3.6.x (Add tests for ToolManager)
* :ghpull:`24219`: Backport PR #23995 on branch v3.6.x (DOC: Lowercase some parameter names)
* :ghpull:`23995`: DOC: Lowercase some parameter names
* :ghpull:`24184`: Add tests for ToolManager
* :ghpull:`24211`: Backport PR #24202 on branch v3.6.x (Bump pypa/cibuildwheel from 2.10.2 to 2.11.1)
* :ghpull:`24214`: Backport PR #24169 on branch v3.6.x ([DOC]: added parent link for ``FuncAnimation`` and ``ArtistAnimation``)
* :ghpull:`24169`: [DOC]: add parent link for ``FuncAnimation`` and ``ArtistAnimation``
* :ghpull:`24202`: Bump pypa/cibuildwheel from 2.10.2 to 2.11.1
* :ghpull:`24206`: Backport PR #24081 on branch v3.6.x (TST: force test with shared test image to run in serial)
* :ghpull:`24181`: Backport PR #24177 on branch v3.6.x (Don't simplify paths used for autoscaling)
* :ghpull:`24200`: Backport PR #24193 on branch v3.6.x (DOC: Explain gridsize in hexbin())
* :ghpull:`24201`: Backport PR #24194 on branch v3.6.x (DOC: Improve plot_directive documentation)
* :ghpull:`24194`: DOC: Improve plot_directive documentation
* :ghpull:`24193`: DOC: Explain gridsize in hexbin()
* :ghpull:`24192`: Backport PR #24187 on branch v3.6.x (DOC: Fix toc structure in explain/interactive)
* :ghpull:`24186`: Backport PR #24157 on branch v3.6.x (test only PR milestoning guidance)
* :ghpull:`24187`: DOC: Fix toc structure in explain/interactive
* :ghpull:`24190`: DOC: fix markup
* :ghpull:`24157`: test only PR milestoning guidance
* :ghpull:`24183`: Backport PR #24178 on branch v3.6.x (Fall back to Python-level Thread for GUI warning)
* :ghpull:`24180`: Backport PR #24173 on branch v3.6.x (TST: convert nose-style tests)
* :ghpull:`24178`: Fall back to Python-level Thread for GUI warning
* :ghpull:`24177`: Don't simplify paths used for autoscaling
* :ghpull:`24173`: TST: convert nose-style tests
* :ghpull:`24174`: Backport PR #24171 on branch v3.6.x (Fix example where wrong variable was used)
* :ghpull:`24176`: Backport PR #24167 on branch v3.6.x (FIX: turn off layout engine tightbbox)
* :ghpull:`24167`: FIX: turn off layout engine tightbbox
* :ghpull:`24171`: Fix example where wrong variable was used
* :ghpull:`24172`: Backport PR #24158 on branch v3.6.x (Fix Qt with PySide6 6.4.0)
* :ghpull:`24158`: Fix Qt with PySide6 6.4.0
* :ghpull:`24165`: Backport PR #24164 on branch v3.6.x (Fix argument order in hist() docstring.)
* :ghpull:`24164`: Fix argument order in hist() docstring.
* :ghpull:`24151`: Backport PR #24149 on branch v3.6.x (FIX: handle input to ax.bar that is all nan)
* :ghpull:`24149`: FIX: handle input to ax.bar that is all nan
* :ghpull:`24146`: Backport PR #24137 on branch v3.6.x (Add note about blitting and zorder in animations)
* :ghpull:`24137`: Add note about blitting and zorder in animations
* :ghpull:`24134`: Backport PR #24130 on branch v3.6.x (DOC: align contour parameter doc with implementation)
* :ghpull:`24130`: DOC: align contour parameter doc with implementation
* :ghpull:`24081`: TST: force test with shared test image to run in serial

Issues (21):

* :ghissue:`20326`: FuncAnimation Named Arguments
* :ghissue:`24332`: [Bug]: backend bug in matplotlib==3.6.1 with python3.11 and PySide6==6.4.0.1
* :ghissue:`24296`: [Doc]:  Axes limits not updated in animate decay
* :ghissue:`24089`: [Bug]: Resizing does not work in WebAgg backend in Safari
* :ghissue:`3657`: matplotlib.pyplot.imsave colormaps some grayscale images before saving them
* :ghissue:`24060`: [TST] Upcoming dependency test failures
* :ghissue:`24264`: [Bug]: Setting matplotlib.pyplot.style.library['seaborn-colorblind'] result in key error on matplotlib v3.6.1
* :ghissue:`23900`: [Doc]: Adding some 3D plots to plot gallery
* :ghissue:`24199`: [Bug]: pick events do not forward mouseevent-key on Linux
* :ghissue:`23969`: [ENH]: Make rubber band more visible
* :ghissue:`23132`: [Bug]: call cmap object on torch.tensor will output first element all 0
* :ghissue:`21349`: [Bug]: Hexbin gridsize interpreted differently for x and y
* :ghissue:`22905`: [Doc]: Duplicated toc entries
* :ghissue:`24094`: [Bug]: macOS: PyPy 3.8 (v7.3.9) threading get_native_id Broken
* :ghissue:`24097`: [Bug]: ax.hist density not auto-scaled when using histtype='step'
* :ghissue:`24148`: remove nose-style test classes
* :ghissue:`24133`: [Bug]: Incorrect crop after constrained layout with equal aspect ratio and bbox_inches = tight
* :ghissue:`24155`: [Bug]: TypeError: int() argument must be a string, a bytes-like object or a number, not 'KeyboardModifier'
* :ghissue:`24127`: [Bug]: ax.bar raises for all-nan data on matplotlib 3.6.1
* :ghissue:`2959`: artists zorder is ignored during animations
* :ghissue:`24121`: [Doc]: Contour functions: auto-generated levels
